If the variable count is not available, the function will assume that
each observation represents one admission, and a variable count will
be created in the output data frame to indicate this.
When assigning observations to cells in a given layer, this function
only assigns observations that have not been previously assigned in a
finer layer. That is, the function assigns observations without
replacement. Assignment with replacement is currently not supported.
For more details see the example vignette by typing:
vignette("semipar_example", package = "healthcare.antitrust")