- data
Dataset of patient choices, with required variables:
cell, provider_id, hospital, sys_id,
party_ind, count. Use other function arguments to
indicate alternative variable names to the default names.
- cell
Name of variable specifying cell to which each observation
has been allocated. Default variable name is cell. Can be
created by cell_defn function.
- provider_id
Name of variable specifying (numeric) provider
identifier. Default variable name is provider_id.
- provider
Name of variable specifying (string) provider name.
Default variable name is provider.
- sys_id
Name of variable specifying (numeric) system identifier.
Default variable name is sys_id.
- focal_sys_id
numeric; list of sys_id's specifying systems of interest
for which diversions will be calculated from. For a merger, this will
typically be the system identifies of the merging parties.
- party_ind
deprecated; use focal_sys_id instead.
- count
Name of variable indicating the number of admissions
represented by the observation. Set = 1 for every row if each
observation represents one admission.
- dropDegenerateCell
logical; specifies how to treat cells with a
100 percent within-system share. If TRUE, observations in degenerate, 100
percent share cells will be ignored in the diversion ratio calculation.
If FALSE, any such individuals will be assigned to the outside option,
but still included in the denominator, so that the inside-option diversion
will total less than 100 percent.
- hosp_id
deprecated; use provider_id instead.
- hospital
deprecated; use provider instead.