Learn R Programming

healthcare.antitrust (version 0.1.4)

healthcare.antitrust-package: healthcare.antitrust: Healthcare Antitrust Analysis

Description

Antitrust analysis of healthcare markets. Contains functions to implement the semiparametric estimation technique described in Raval, Rosenbaum, and Tenn (2017) "A Semiparametric Discrete Choice Model: An Application to Hospital Mergers" tools:::Rd_expr_doi("10.1111/ecin.12454").

Arguments

Author

Maintainer: Matthew T Panhans mpanhans@gmail.com (ORCID)

Details

For more details see the example vignette by typing: vignette("semipar_example", package = "healthcare.antitrust")

See Also