Antitrust analysis of healthcare markets. Contains functions to implement the semiparametric estimation technique described in Raval, Rosenbaum, and Tenn (2017) "A Semiparametric Discrete Choice Model: An Application to Hospital Mergers" tools:::Rd_expr_doi("10.1111/ecin.12454").
Maintainer: Matthew T Panhans mpanhans@gmail.com (ORCID)
For more details see the example vignette by typing:
vignette("semipar_example", package = "healthcare.antitrust")
Useful links: